@@ -119,11 +119,11 @@ App::Licensecheck - functions for a simple license checker for source files
 
 =head1 VERSION
 
-Version v3.2.8
+Version v3.2.9
 
 =cut
 
-our $VERSION = version->declare('v3.2.8');
+our $VERSION = version->declare('v3.2.9');
 
 =head1 SYNOPSIS
 
@@ -528,11 +528,14 @@ sub clean_comments
 	return $_;
 }
 
+my $html_xml_tags_re = qr/<\/?(?:p|br|ref)(?:\s[^>]*)?>/i;
+
 sub clean_cruft
 {
 	local $_ = shift or return q{};
 
-	s/<\/?(?:p|br)>//gi;
+	# strip common html and xml tags
+	s/$html_xml_tags_re//g;
 
 	# TODO: decode latin1/UTF-8/HTML data instead
 	s/\xcb\x97|\xe2\x80[\x90-\x95|\xe2\x81\x83|\xe2\x88\x92|\xef\x89\xa3|\xef\xbc\x8d]|[&](?:ndash|mdash|horbar|minus|[#](?:727|820[8-9]|821[0-3]|8259|8722|65123|65293|x727|z201[0-5]|x2043|x2212|xFE63|xFF0D))[;]/-/gm;
@@ -552,7 +555,8 @@ sub clean_cruft_and_spaces
 	# (example: disclaimers in GNU autotools file "install-sh")
 	s/-\r?\n//g;
 
-	s/<\/?(?:p|br)>//gi;
+	# strip common html and xml tags
+	s/$html_xml_tags_re//g;
 
 	tr/\t\r\n/ /;
 
